get_which_gbfs_feeds: Get dataframe of bikeshare feeds released by a city
Description
Of the different types of feeds supplied by the gbfs,
some are required, some are conditionally required, and some are
optional. This function grabs a list of each of the feeds supplied
by a given city, as well as the URLs to access them.
Usage
get_which_gbfs_feeds(city)
Arguments
city
A character string that can be matched to a city or a url to
an active gbfs .json feed. See [get_gbfs_cities()] for a
current list of available cities.
Value
A data.frame containing the feeds supplied by
a city. . The `feed` column supplies the name of the relevant .json feeds,
while the entries in the `URL` column supply the feeds themselves.